==> synfigstudio_0.64.1.orig.tar.gz: synfigstudio-0.64.1/src/synfigapp/actions/valuedescremovesmart.h <==
/* === S Y N F I G ========================================================= */
/*!	\file valuedescremovesmart.h
**	\brief Template File for multiple value descriptions remove action.
*
*	The action will remove smart, multiple selection of value descriptions
*	for ValueNode_Dynamic items
**	$Id$
**
**	\legal
**	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
**	Copyright (c) 2011 Carlos López González
**
**	This package is free software; you can redistribute it and/or
**	modify it under the terms of the GNU General Public License as
**	published by the Free Software Foundation; either version 2 of
**	the License, or (at your option) any later version.
**
**	This package is distributed in the hope that it will be useful,
**	but WITHOUT ANY WARRANTY; without even the implied warranty of
**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
**	General Public License for more details.
**	\endlegal
*/
/* ========================================================================= */

/* === S T A R T =========================================================== */

#ifndef __SYNFIG_APP_ACTION_VALUEDESCREMOVESMART_H
#define __SYNFIG_APP_ACTION_VALUEDESCREMOVESMART_H

/* === H E A D E R S ======================================================= */

#include <synfigapp/action.h>
#include <synfig/valuenode_dynamiclist.h>

/* === M A C R O S ========================================================= */

/* === T Y P E D E F S ===================================================== */

/* === C L A S S E S & S T R U C T S ======================================= */

namespace synfigapp {
namespace Action {

class ValueDescRemoveSmart :
	public Super
{
private:
	// ValueNodes is a map of value nodes parents and the indexes to remove
	typedef std::map<synfig::ValueNode_DynamicList::Handle, std::vector<int> > ValueNodes;
	ValueNodes value_nodes;
	// optional parameters
	synfig::Time time;
	synfig::Real origin;
public:
	ValueDescRemoveSmart();
	static ParamVocab get_param_vocab();
	static bool is_candidate(const ParamList &x);
	virtual bool set_param(const synfig::String& name, const Param &);
	virtual bool is_ready()const;
	virtual void prepare();
	ACTION_MODULE_EXT
};

}; // END of namespace action
}; // END of namespace studio

/* === E N D =============================================================== */

#endif

==> synfigstudio_1.2.1.orig.tar.gz: synfigstudio-1.2.1/src/synfigapp/actions/valuedescremovesmart.h <==
/* === S Y N F I G ========================================================= */
/*!	\file valuedescremovesmart.h
**	\brief Template File for multiple value descriptions remove action.
*
*	The action will remove smart, multiple selection of value descriptions
*	for ValueNode_Dynamic items
**	$Id$
**
**	\legal
**	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
**	Copyright (c) 2011 Carlos López González
**
**	This package is free software; you can redistribute it and/or
**	modify it under the terms of the GNU General Public License as
**	published by the Free Software Foundation; either version 2 of
**	the License, or (at your option) any later version.
**
**	This package is distributed in the hope that it will be useful,
**	but WITHOUT ANY WARRANTY; without even the implied warranty of
**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
**	General Public License for more details.
**	\endlegal
*/
/* ========================================================================= */

/* === S T A R T =========================================================== */

#ifndef __SYNFIG_APP_ACTION_VALUEDESCREMOVESMART_H
#define __SYNFIG_APP_ACTION_VALUEDESCREMOVESMART_H

/* === H E A D E R S ======================================================= */

#include <synfigapp/action.h>
#include <synfig/valuenodes/valuenode_dynamiclist.h>

/* === M A C R O S ========================================================= */

/* === T Y P E D E F S ===================================================== */

/* === C L A S S E S & S T R U C T S ======================================= */

namespace synfigapp {
namespace Action {

class ValueDescRemoveSmart :
	public Super
{
private:
	// ValueNodes is a map of value nodes parents and the indexes to remove
	typedef std::map<synfig::ValueNode_DynamicList::Handle, std::vector<int> > ValueNodes;
	ValueNodes value_nodes;
	// optional parameters
	synfig::Time time;
	synfig::Real origin;
public:
	ValueDescRemoveSmart();
	static ParamVocab get_param_vocab();
	static bool is_candidate(const ParamList &x);
	virtual bool set_param(const synfig::String& name, const Param &);
	virtual bool is_ready()const;
	virtual void prepare();
	ACTION_MODULE_EXT
};

}; // END of namespace action
}; // END of namespace studio

/* === E N D =============================================================== */

#endif
